from distutils.core import setup

setup(
    name            ='sanitiz',
    version         ='1.0.0',
    py_modules      =['sanitiz'],
    author          ='hpython',
    author_email    ='hfpython@headfirstlabs.com',
    url             ='http://www.headfirstlabs.com',
    description     ='Developed by Head First python that replaces colons and hyphens with periods within lists',
    )
